@@ -1,5 +1,6 @@
 from datetime import date, timedelta
 
+from .config_helper import ConfigHelper
 from .soozaccess import SoozAccess
 
 # root
@@ -17,15 +18,16 @@ def main():
     start_date = date(2020, 1, 1)
     n_dates = 5
 
-    SoozAccess.host = "http://localhost:3000"
-    SoozAccess.verbose = True
+    ConfigHelper.host = "http://localhost:3000"
+    ConfigHelper.verbose = True
+
     SoozAccess.prepare_users(group, users)
 
     # create data
     for name in users:
         with SoozAccess(name, name) as user:
             for day in daterange(start_date, n_dates):
-                user.put_response(2, 2, 3, day.strftime("%Y-%m-%d"))
+                user.responses.put_response(2, 21, 3, day.strftime("%Y-%m-%d"))
 
 
 if __name__ == "__main__":
